@@ -52,6 +52,9 @@ extern "C" int initializeWinsockIfNecessary();
 ipv4AddressBits SendingInterfaceAddr = INADDR_ANY;
 ipv4AddressBits ReceivingInterfaceAddr = INADDR_ANY;
 in6_addr ReceivingInterfaceAddr6 = IN6ADDR_ANY_INIT;
+#ifdef SO_BINDTODEVICE
+char InterfaceBindToDevice[128] = {0};
+#endif
 
 static void socketErr(UsageEnvironment& env, char const* errorMsg) {
   env.setResultErrMsg(errorMsg);
@@ -120,6 +123,16 @@ int setupDatagramSocket(UsageEnvironment& env, Port port, int domain) {
     return newSocket;
   }
 
+#ifdef SO_BINDTODEVICE
+  if (InterfaceBindToDevice[0] != '\0') {
+    if (setsockopt(newSocket, SOL_SOCKET, SO_BINDTODEVICE, InterfaceBindToDevice, strlen(InterfaceBindToDevice)) < 0) {
+      socketErr(env, "setsockopt(SO_BINDTODEVICE) error: ");
+      closeSocket(newSocket);
+      return -1;
+    }
+  }
+#endif
+
   int reuseFlag = groupsockPriv(env)->reuseFlag;
   reclaimGroupsockPriv(env);
   if (setsockopt(newSocket, SOL_SOCKET, SO_REUSEADDR,
@@ -303,6 +316,16 @@ int setupStreamSocket(UsageEnvironment& env, Port port, int domain,
     return newSocket;
   }
 
+#ifdef SO_BINDTODEVICE
+  if (InterfaceBindToDevice[0] != '\0') {
+    if (setsockopt(newSocket, SOL_SOCKET, SO_BINDTODEVICE, InterfaceBindToDevice, strlen(InterfaceBindToDevice)) < 0) {
+      socketErr(env, "setsockopt(SO_BINDTODEVICE) error: ");
+      closeSocket(newSocket);
+      return -1;
+    }
+  }
+#endif
+
   int reuseFlag = groupsockPriv(env)->reuseFlag;
   reclaimGroupsockPriv(env);
   if (setsockopt(newSocket, SOL_SOCKET, SO_REUSEADDR,
